@@ -78,8 +78,6 @@ class ResetPasswordVerifySerializer(serializers.Serializer):  # noqa
         Check if passwords matched and if token is valid.
         """
         data['token'] = validate_token_by_type(data['token'], ActivationCode.CodeTypes.RESET_PASSWORD)
-        if data['password'] != data['confirm_password']:
-            raise serializers.ValidationError("Passwords does not match")
         return data
 
 
@@ -88,6 +86,12 @@ class ResetPasswordConfirmSerializer(ResetPasswordVerifySerializer):  # noqa
     confirm_password = serializers.CharField(label="Confirm password", required=True,
                                              allow_null=False, allow_blank=False)
 
+    def validate(self, data):
+        data = super().validate(data)
+        if data['password'] != data['confirm_password']:
+            raise serializers.ValidationError("Passwords does not match")
+        return data
+
 
 class LoginSerializer(TokenObtainPairSerializer):  # noqa
     @classmethod
@@ -137,3 +141,22 @@ class CustomTokenRefreshSerializer(TokenRefreshSerializer):  # noqa
         data = {'access': str(refresh.access_token)}
 
         return data
+
+
+class TokenByCookieSerializer(TokenRefreshSerializer):
+    service_token = serializers.CharField(required=False)
+
+    def validate(self, attrs):
+        refresh = RefreshToken(attrs['refresh'])
+        user = User.objects.filter(pk=refresh.payload.get("user_id")).first()
+        if not user:
+            raise AuthenticationFailed('User is inactive', code='user_inactive')
+
+        UserLogs.objects.create(
+            service=user.service,
+            user=user,
+            username=user,
+            type_log=LogsType.REFRESH_TOKEN
+        )
+
+        return super().validate(attrs)
