@@ -5,17 +5,18 @@ from drf_yasg import openapi
 from drf_yasg.utils import swagger_auto_schema, no_body
 from rest_framework import status
 from rest_framework.decorators import action
+from rest_framework.generics import GenericAPIView
 from rest_framework.response import Response
 from rest_framework_simplejwt.settings import api_settings
 from rest_framework_simplejwt.views import TokenViewBase
 
 from drf_auth_service.authentication.serializers import CustomTokenRefreshSerializer, \
-    ReturnRegisterSerializer, ReturnAccessTokenSerializer
+    ReturnRegisterSerializer, ReturnAccessTokenSerializer, TokenByCookieSerializer
 from drf_auth_service.common.managers import BaseManager
 from drf_auth_service.common.mixins import GenericEBSViewSet
 from drf_auth_service.common.register_backends import RegisterManager
 from drf_auth_service.models import SSOUser
-from drf_auth_service.settings import settings
+from drf_auth_service.settings import settings, User
 
 jwt_response = openapi.Response('Respond with jwt access&refresh token', ReturnRegisterSerializer)
 refresh_response = openapi.Response('Respond with jwt access token, ', ReturnAccessTokenSerializer)
@@ -103,7 +104,7 @@ class LoginViewSet(TokenViewBase):
         )
         response.cookies[settings.COOKIE_KEY]['samesite'] = 'None'
 
-        SSOUser.objects.filter(username=request.data.get('username')).update(last_login=timezone.now())
+        User.objects.filter(username=request.data.get('username')).update(last_login=timezone.now())
 
         return response
 
@@ -116,3 +117,16 @@ class EBSTokenRefreshView(TokenViewBase):
     def post(self, request, *args, **kwargs):
         api_settings.SIGNING_KEY = request.service.secret_token
         return super().post(request, *args, **kwargs)
+
+
+class TokenByCookieView(GenericAPIView):
+    permission_classes = ()
+    serializer_class = TokenByCookieSerializer
+
+    def get(self, request):
+        refresh_token = request.COOKIES.get(settings.COOKIE_KEY)
+        serializer = TokenByCookieSerializer(data={'refresh': refresh_token})
+        if not serializer.is_valid():
+            return Response({settings.COOKIE_KEY: ["Cookie token not valid"]}, status=status.HTTP_403_FORBIDDEN)
+        return Response({'refresh': refresh_token, **serializer.validated_data}, status=status.HTTP_200_OK)
+
