@@ -1,9 +1,8 @@
 from abc import abstractmethod
-from urllib.parse import urlparse
 
 import sib_api_v3_sdk
 from django.core.exceptions import ImproperlyConfigured
-from django.core.mail import EmailMessage
+from django.core.mail import send_mail
 from django.core.mail.backends.smtp import EmailBackend
 from django.template import TemplateDoesNotExist
 from django.template.loader import render_to_string
@@ -91,11 +90,8 @@ class HtmlTemplateBackend(BaseEmailBackend):
             email_html_message = render_to_string((html_template, context.get('default_template')), context)
         except TemplateDoesNotExist:
             raise ImproperlyConfigured(F"{html_template} invalid path in settings")
-        self.email_backend.open()
-        email = EmailMessage(context['subject'], email_html_message, self.configs['HTML_DEFAULT_FROM_EMAIL'],
-                             [context['email']], [])
-        self.email_backend.send_messages([email])
-        self.email_backend.close()
+        send_mail(context['subject'], email_html_message, self.configs['HTML_DEFAULT_FROM_EMAIL'],
+                  [context['email']], connection=self.email_backend, html_message=email_html_message)
 
     def config_backend(self):
         self.email_backend = EmailBackend(host=self.configs['EMAIL_HOST'],
