@@ -27,7 +27,7 @@ class AbstractSSOUser(AbstractBaseUser):
     register_type = models.CharField(max_length=100, choices=RegisterType.choices, default=RegisterType.EMAIL)
     USERNAME_FIELD = 'username'
     objects = BaseUserManager()
-    created_at = models.DateTimeField(default=timezone.now())
+    created_at = models.DateTimeField(default=timezone.now)
 
     class Meta:
         db_table = '"users"'
