@@ -58,7 +58,7 @@ default_sso_settings = {
     "MAILCHIMP_SECRET_KEY": None,
     "SEND_CONFIRMATION": True,
     "RESET_PASSWORD_EXPIRE": 24,
-    "SEND_RESET_PASSWORD_PREFIX": '',
+    "RESET_PASSWORD_URL": '',
     "SEND_CONFIRMATION_URL": 'https://example.com/confirm-email/',
     "TWILIO_ACCOUNT_SID": "AC6b3fc1744aa63d35235a4fb01241e71a",
     "TWILIO_AUTH_TOKEN": "a3e0f68829427c69dbb94cb4e95ff638",
@@ -103,7 +103,9 @@ default_sso_settings = {
     "PERMISSIONS": ObjDict({
         "USER_PERMISSIONS": "drf_auth_service.users.permissions.USER_PERMISSIONS",
         "SERVICE_PERMISSIONS": "drf_auth_service.services.permissions.SERVICE_PERMISSIONS",
-        "AUTHENTICATION_PERMISSIONS": "drf_auth_service.authentication.permissions.AUTHENTICATION_PERMISSIONS"
+        "AUTHENTICATION_PERMISSIONS": "drf_auth_service.authentication.permissions.AUTHENTICATION_PERMISSIONS",
+        "SERVICE_TOKEN_PERMISSION": "drf_auth_service.common.permissions.ServiceTokenPermission",
+        "SECRET_SERVICE_TOKEN_PERMISSION": "drf_auth_service.common.permissions.SecretServiceTokenPermission",
     }),
     "BACKENDS": ObjDict({
         "SMS_BACKEND": "drf_auth_service.common.sms_backends.TwilioBackend",
@@ -207,43 +209,7 @@ class Settings:
         from drf_auth_service.models import Service, Config
 
         if getattr(self, 'WORK_MODE') == 'standalone' and Service.objects.count() == 0:
-            service = Service.objects.create(name='Default configs')
-            configs = []
-
-            for key, val in self.__dict__.items():
-                if key in SETTINGS_TO_IMPORT_IN_DB:
-                    if type(val) == ObjDict or type(val) == dict:
-
-                        for dict_key, dict_value in val.items():
-                            if not type(dict_value) == list:
-                                configs.append(Config(
-                                    type='str',
-                                    value=dict_value,
-                                    key=dict_key,
-                                    service=service
-                                ))
-
-                    elif type(val) == list:
-                        value = ''
-                        for list_value in val:
-                            value += f"{list_value},"
-
-                        configs.append(Config(
-                            type='str',
-                            value=value.rstrip(','),
-                            key=key,
-                            service=service
-                        ))
-
-                    else:
-                        configs.append(Config(
-                            type=type(val).__name__ if type(val) is not None else 'str',
-                            value=str(val),
-                            key=key,
-                            service=service
-                        ))
-
-            Config.objects.bulk_create(configs)
+            Service.objects.create(name='Default configs')
 
     def _validate_configs(self):
 
